Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/mono/libgit2sharp.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorKeith Dahlby <dahlbyk@gmail.com>2012-06-10 01:22:16 +0400
committerKeith Dahlby <dahlbyk@gmail.com>2012-06-10 01:22:46 +0400
commit293f26e074bcd44cc198e3f177b8093da2b92211 (patch)
tree6a95edcf0cc653b7af3a234ccb65c267386c891f /LibGit2Sharp/Configuration.cs
parent1ed8a4fe7933315e20eaf4d130436df2d62aad75 (diff)
Rename Delete to Unset in Configuration
Diffstat (limited to 'LibGit2Sharp/Configuration.cs')
-rw-r--r--LibGit2Sharp/Configuration.cs17
1 files changed, 14 insertions, 3 deletions
diff --git a/LibGit2Sharp/Configuration.cs b/LibGit2Sharp/Configuration.cs
index e1cc0c25..ca292660 100644
--- a/LibGit2Sharp/Configuration.cs
+++ b/LibGit2Sharp/Configuration.cs
@@ -139,11 +139,11 @@ namespace LibGit2Sharp
#endregion
/// <summary>
/// Delete a configuration variable (key and value).
/// </summary>
- /// <param name = "key">The key to delete.</param>
+ /// <param name = "key">The key to unset.</param>
/// <param name = "level">The configuration file which should be considered as the target of this operation</param>
- public void Delete(string key, ConfigurationLevel level = ConfigurationLevel.Local)
+ public void Unset(string key, ConfigurationLevel level = ConfigurationLevel.Local)
{
ConfigurationSafeHandle h = RetrieveConfigurationHandle(level);
@@ -159,6 +159,17 @@ namespace LibGit2Sharp
}
/// <summary>
+ /// Delete a configuration variable (key and value).
+ /// </summary>
+ /// <param name = "key">The key to delete.</param>
+ /// <param name = "level">The configuration file which should be considered as the target of this operation</param>
+ [Obsolete("This method will be removed in the next release. Please use Unset() instead.")]
+ public void Delete(string key, ConfigurationLevel level = ConfigurationLevel.Local)
+ {
+ Unset(key, level);
+ }
+
+ /// <summary>
/// Performs application-defined tasks associated with freeing, releasing, or resetting unmanaged resources.
/// </summary>
protected virtual void Dispose(bool disposing)
@@ -139,11 +139,11 @@ namespace LibGit2Sharp
#endregion
/// <summary>
- /// Delete a configuration variable (key and value).
+ /// Unset a configuration variable (key and value).
/// </summary>